@@ -257,3 +257,31 @@ BEGIN {
 1;
 
 __END__
+
+=head1 NAME
+
+Text::Template::Simple::Constants - Constants for Text::Template::Simple
+
+=head1 SYNOPSIS
+
+TODO
+
+=head1 DESCRIPTION
+
+Constants for Text::Template::Simple.
+
+=head1 AUTHOR
+
+Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2004-2007 Burak GE<252>rsoy. All rights reserved.
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify 
+it under the same terms as Perl itself, either Perl version 5.8.8 or, 
+at your option, any later version of Perl 5 you may have available.
+
+=cut
